import express from "express";
import { assert } from "console";
import routes from "./routes";
import http from "http";
import Websocket from "./websocket";
import expressWinston from "express-winston";
import winston from "winston";

export default class Api {
    declare app: express.Application;
    declare server: http.Server;
    declare wss: Websocket; 
    constructor(port: number) {
        this.app = express();
        this.app.use(expressWinston.logger({
            transports: [
                new winston.transports.Console()
            ],
            format: winston.format.combine(
                winston.format.colorize(),
                winston.format.cli(),
            ),
            meta: true,
            msg: "HTTP {{req.method}} {{req.url}}",
            expressFormat: true, 
            colorize: true,
            // ignoreRoute: function (req, res) { return false; } // optional: allows to skip some log messages based on request and/or response
        }));
        this.app.use("/api", routes);
        this.server = http.createServer(this.app);
        this.server.listen(port);
        this.wss = new Websocket(this.server);
    }
}
